Struct sod_log::LogDebugService
source · pub struct LogDebugService<'a> { /* private fields */ }Expand description
A sod::Service that logs Debug input at a configured log level to log::log, returning the input as output.
Implementations
sourceimpl<'a> LogDebugService<'a>
impl<'a> LogDebugService<'a>
sourcepub fn new<S: Into<Cow<'a, str>>>(level: Level, prefix: S) -> Self
pub fn new<S: Into<Cow<'a, str>>>(level: Level, prefix: S) -> Self
Log input at the given log level
Arguments
level- The log levelprefix- A prefix to prepend to the beginning of the log statment