Struct sod_log::LogDisplayService
source · pub struct LogDisplayService<'a> { /* private fields */ }Expand description
A sod::Service that logs Display input at a configured log level to log::log, returning the input as output.
This service is useful for logging an event as it passed through a service chain.
Implementations
sourceimpl<'a> LogDisplayService<'a>
impl<'a> LogDisplayService<'a>
sourcepub fn new<S: Into<Cow<'a, str>>>(level: Level, prefix: S) -> Self
pub fn new<S: Into<Cow<'a, str>>>(level: Level, prefix: S) -> Self
Log input at the given log level
Arguments
level- The log levelprefix- A prefix to prepend to the beginning of the log statment