pub struct LogDisplayService<'a> { /* private fields */ }
A sod::Service that logs Display input at a configured log level to log::log, returning the input as output.

This service is useful for logging an event as it passed through a service chain.

Implementations

source

impl<'a> LogDisplayService<'a>

source

pub fn new<S: Into<Cow<'a, str>>>(level: Level, prefix: S) -> Self

Log input at the given log level

Arguments
  • level - The log level
  • prefix - A prefix to prepend to the beginning of the log statment
source

pub fn debug<S: Into<Cow<'a, str>>>(prefix: S) -> Self

Log as Level::Debug

Arguments
  • prefix - A prefix to prepend to the beginning of the log statment
source

pub fn error<S: Into<Cow<'a, str>>>(prefix: S) -> Self

Log as Level::Error

Arguments
  • prefix - A prefix to prepend to the beginning of the log statment
source

pub fn info<S: Into<Cow<'a, str>>>(prefix: S) -> Self

Log as Level::Info

Arguments
  • prefix - A prefix to prepend to the beginning of the log statment
source

pub fn trace<S: Into<Cow<'a, str>>>(prefix: S) -> Self

Log as Level::Trace

Arguments
  • prefix - A prefix to prepend to the beginning of the log statment
source

pub fn warn<S: Into<Cow<'a, str>>>(prefix: S) -> Self

Log as Level::Warn

Arguments
  • prefix - A prefix to prepend to the beginning of the log statment